==> nonebot-plugin-covid19-news-0.5.4.tar.gz: nonebot-plugin-covid19-news-0.5.4/README.md <==
# nonebot-plugin-covid19-news 😷
国内新冠消息查询

## 安装使用
### 方法一 使用nb-cli
```
nb plugin install nonebot_plugin_covid19_news
```

### 方法二 使用pip
```
# pip 下载包
pip install nonebot_plugin_covid19_news


# 配置 pyproject.toml

plugins = [
    ...,
    "nonebot_plugin_covid19_news",
    ]

```


## 指令列表

### 查询地方疫情信息（风险等级 新增 目前确诊） 
指令: `城市名 + 疫情`  
事例: `天津疫情` 


### 查询地方出入政策  
指令: `城市名 + 疫情政策`  
事例: `广州疫情政策`

### 查询城市风险地区
*只限查询大陆地级市或直辖市*  
指令: `城市名 + 风险地区` 


###  疫情信息更新推送 
指令: `关注疫情 + 城市名`  
事例: `关注疫情 北京`

### 取消推送
指令: `取消疫情 + 城市名` / `取消关注疫情 + 城市名` / `取消推送疫情 + 城市名`

## 其他功能

### 异常新增警告
对国内新增异常的地区进行推送提醒  
需要修改配置文件`.env.dev`

### 图片发送
1. 下载 `fonts/` 目录中字体 放到 `bot.py`同级目录的`data/fonts`中  
2. 配置`.env.dev`  添加以下一段
```
covid19_message_type = "image"
```



## 配置文件说明
```
// 异常新增警告
covid19 = {"notice":"True", "red-line": 1000, "filter":[],"group":[]}

    // 字段说明
    // notice: str                仅为 True 时开启功能
    // red-line: int              新增达到该数值会, 发送疫情信息
    // filter: List[str]          过滤城市/地区 （默认过滤 香港 台湾）
    // group: List[int] | str     发送到群; 为 all 时发送到所有群

// 消息发送类型（text, image）
covid19_message_type = "image"

```

## 更新log 📝
### 2022.2.14
添加取消推送功能

### 2022.2.15
添加风险地区查询功能功能

### 2022.3.23
无症状与确诊分开显示数据

### 2022.3.28
添加地区新增异常警告功能

### 2022.4.14
优化更新数据与推送的逻辑

### 2022.5.30
关注地区零新增不再推送（有无新增才是重点）

### 2022.6.20
出行政策以合并消息发送到群聊  （最近好忙 有些问题不能及时处理 见谅）

### 2022.7.31
图片方式发送信息 （默认发送文字 如需图片方式发送 需修改配置`.env.dev`）

## 注意⚠️
数据更新、消息推送 目前以30分钟为周期  
本插件使用腾讯api, 在疫情发生地(频繁大规模核酸) 数据存在一定滞后性; 确诊数量与其他api获取到的不一样  (感觉有人在开摆!), 真实数据请以国家公布为准。
## 后续可能添加的功能
- [x] 定时推送关注城市疫情信息 ⏰
- [ ] 查询省份返回主要城市疫情信息 📍
- [ ] 一周内疫情变化图表 📈
- [ ] 添加其他查询api 🔧
- [x] 图片形式发送
- 有想法欢迎提 issue 💡

==> nonebot-plugin-covid19-news-0.6.0.2.tar.gz: nonebot-plugin-covid19-news-0.6.0.2/README.md <==
# nonebot-plugin-covid19-news 😷
国内新冠消息查询

## 安装使用
### 方法一 使用nb-cli
```
nb plugin install nonebot_plugin_covid19_news
```

### 方法二 使用pip
```
# pip 下载包
pip install nonebot_plugin_covid19_news


# 配置 pyproject.toml

plugins = [
    ...,
    "nonebot_plugin_covid19_news",
    ]

```


## 指令列表

### 查询地方疫情信息（风险等级 新增 目前确诊） 
指令: `城市名 + 疫情`  
事例: `天津疫情` 


### 查询地方出入政策  
指令: `城市名 + 疫情政策`  
事例: `广州疫情政策`

### 查询城市风险地区
*只限查询大陆地级市或直辖市*  
指令: `城市名 + 风险地区` 


###  疫情信息更新推送 
指令: `关注疫情 + 城市名`  
事例: `关注疫情 北京`

### 取消推送
指令: `取消疫情 + 城市名` / `取消关注疫情 + 城市名` / `取消推送疫情 + 城市名`

## 其他功能

### 异常新增警告
对国内新增异常的地区进行推送提醒  
需要修改配置文件`.env.dev`

### 图片发送
1. 下载 `fonts/` 目录中字体 放到 `bot.py`同级目录的`data/fonts`中  
2. 配置`.env.dev`  添加以下一段
```
covid19_message_type = "image"
```



## 配置文件说明
```
// 异常新增警告
covid19 = {"notice":"True", "red-line": 1000, "filter":[],"group":[]}

    // 字段说明
    // notice: str                仅为 True 时开启功能
    // red-line: int              新增达到该数值会, 发送疫情信息
    // filter: List[str]          过滤城市/地区 （默认过滤 香港 台湾）
    // group: List[int] | str     发送到群; 为 all 时发送到所有群

// 消息发送类型（text, image）
covid19_message_type = "image"

```

## 更新log 📝
### 2022.2.14
添加取消推送功能

### 2022.2.15
添加风险地区查询功能功能

### 2022.3.23
无症状与确诊分开显示数据

### 2022.3.28
添加地区新增异常警告功能

### 2022.4.14
优化更新数据与推送的逻辑

### 2022.5.30
关注地区零新增不再推送（有无新增才是重点）

### 2022.6.20
出行政策以合并消息发送到群聊  （最近好忙 有些问题不能及时处理 见谅）

### 2022.7.31
图片方式发送信息 （默认发送文字 如需图片方式发送 需修改配置`.env.dev`）

### 2022.8.9
风险地区按等级排序发送

### 2022.8.27
群发消息风控提示 （建议设置图片发送）

### 2022.10.8
查询省级疫情政策与风险政策反馈省内市级地区疫情简讯

## 注意⚠️
数据更新、消息推送 目前以30分钟为周期  
本插件使用腾讯api, 在疫情发生地(频繁大规模核酸) 数据存在一定滞后性; 确诊数量与其他api获取到的不一样  (感觉有人在开摆!), 真实数据请以国家公布为准。
## 后续可能添加的功能
- [x] 定时推送关注城市疫情信息 ⏰
- [x] 查询省份返回主要城市疫情信息 📍
- [ ] 一周内疫情变化图表 📈
- [ ] 添加其他查询api 🔧
- [x] 图片形式发送
- [ ] 同名地区问题 (吉林省 吉林市 / 海南省 海南州 ...)
- 有想法欢迎提 issue 💡
